package com.iqball.app

import android.os.Bundle
import android.util.Log
import androidx.activity.ComponentActivity
import androidx.activity.compose.setContent
import androidx.compose.foundation.layout.fillMaxSize
import androidx.compose.material3.MaterialTheme
import androidx.compose.material3.Surface
import androidx.compose.runtime.Composable
import androidx.compose.ui.Modifier
import com.google.gson.Gson
import com.iqball.app.api.EitherBodyConverter
import com.iqball.app.api.EitherCallAdapterFactory
import com.iqball.app.api.service.AuthService
import com.iqball.app.api.service.IQBallService
import com.iqball.app.page.HomePage
import com.iqball.app.page.RegisterPage
import com.iqball.app.ui.theme.IQBallTheme
import kotlinx.coroutines.runBlocking
import okhttp3.OkHttpClient
import retrofit2.Retrofit
import retrofit2.converter.gson.GsonConverterFactory
import retrofit2.create

class MainActivity : ComponentActivity() {
    override fun onCreate(savedInstanceState: Bundle?) {
        super.onCreate(savedInstanceState)
        val gson = Gson()

        val retrofit = Retrofit.Builder()
            .addConverterFactory(EitherBodyConverter.create())
            .addConverterFactory(GsonConverterFactory.create(gson))
            .addCallAdapterFactory(EitherCallAdapterFactory.create(gson))
            .baseUrl("https://iqball.maxou.dev/api/dotnet-master/")
            .client(
                OkHttpClient.Builder()
                    .addInterceptor { it.proceed(it.request()) }
                    .build()
            )
            .build()

        val service = retrofit.create<IQBallService>()

        setContent {
            IQBallTheme(darkTheme = false, dynamicColor = false) {
                // A surface container using the 'background' color from the theme
                Surface(
                    modifier = Modifier.fillMaxSize(),
                    color = MaterialTheme.colorScheme.background
                ) {
                    HomePage(service)
                }
            }
        }
    }
}